<?php

/**
 * @file
 * Template overrides as well as (pre-)process and alter hooks for the
 * WCM Omega theme.
 */

// force regions to display without blocks
function wcm_omega_page_alter(&$page) {
  $regions = system_region_list($GLOBALS['theme'], REGIONS_ALL);

  if (array_key_exists('osu_navbar', $regions)) {
		$page['osu_navbar'] = array(
			'#region' => 'osu_navbar',
			'#weight' => '-10',
			'#theme_wrappers' => array('region'),
		);
	}

  if (array_key_exists('masthead', $regions)) {
		$page['masthead'] = array(
			'#region' => 'masthead',
			'#weight' => '-9',
			'#theme_wrappers' => array('region'),
		);
	}

  if (empty($page['main_menu_second']) && array_key_exists('main_menu_second', $regions)) {
		$page['main_menu_second'] = array(
			'#region' => 'main_menu_second',
			'#weight' => '-8',
			'#theme_wrappers' => array('region'),
		);
	}

  if (array_key_exists('footer_1', $regions)) {
		$page['footer_1'] = array(
			'#region' => 'footer_1',
			'#weight' => '-7',
			'#theme_wrappers' => array('region'),
		);
	}

  if (empty($page['footer_2']) && array_key_exists('footer_2', $regions)) {
    $page['footer_2'] = array(
      '#region' => 'footer_2',
      '#weight' => '-7',
      '#theme_wrappers' => array('region'),
    );
  }

  if (empty($page['footer_3']) && array_key_exists('footer_3', $regions)) {
    $page['footer_3'] = array(
      '#region' => 'footer_3',
      '#weight' => '-7',
      '#theme_wrappers' => array('region'),
    );
  }
}

/*
 * Implements hook_omega_theme_libraries_info().
 */
function wcm_omega_omega_theme_libraries_info() {
  $libraries['modernizr'] = array(
    'name' => t('Modernizr'),
    'description' => t('Modernizr is a JavaScript library that detects HTML5 and CSS3 features in the user?s browser.'),
    'vendor' => 'Modernizr',
    'vendor url' => 'http://modernizr.com/',
    'package' => t('Polyfills'),
    'files' => array(
      'js' => array(
        'modernizr.min.js' => array(
          'weight' => 130,
          'every_page' => TRUE,
        ),
      ),
    ),
    'variants' => array(
      'source' => array(
        'name' => t('Source'),
        'description' => t('During development it might be useful to include the source files instead of the minified version.'),
        'files' => array(
          'js' => array(
            'modernizr.js' => array(
              'weight' => 130,
              'every_page' => TRUE,
            ),
          ),
        ),
      ),
    ),
  );

  return $libraries;
}

/**
 * Implements hook_css_alter().
 *
 * Remove core and contrib scripts associated with accordions.
 */
function wcm_omega_js_alter(&$js) {
  unset($js[libraries_get_path('superfish') . '/aria.js']);
  unset($js['misc/ui/jquery.ui.accordion.min.js']);
  unset($js[drupal_get_path('module', 'panopoly_theme') . '/js/panopoly-accordion.js']);
  unset($js[drupal_get_path('module', 'views_accordion') . '/views-accordion.js']);
  unset($js[drupal_get_path('module', 'views_nested_accordion') .'/js/views-nested-accordion.js']);
}

/**
 * Implements hook_css_alter().
 *
 * Remove core and contrib styles associated with accordions.
 */
function wcm_omega_css_alter(&$css) {
  unset($css['misc/ui/jquery.ui.accordion.css']);
  unset($css[drupal_get_path('module', 'views_accordion') . '/views-accordion.css']);
  unset($css[drupal_get_path('module', 'views_nested_accordion') . '/css/views-nested-accordion.css']);
}

/**
 * Implements hook_views_pre_render().
 *
 * Add classes to views using accordion style plugins.
 */
function wcm_omega_views_pre_render(&$view) {
  if ($view->style_plugin->plugin_name == 'views_accordion') {
    $view->display_handler->set_option('css_class', 'views-accordion');
  }
  if ($view->style_plugin->plugin_name == 'views_nested_accordion') {
    $view->display_handler->set_option('css_class', 'views-nested-accordion');
  }
}
